@@ -1,8 +1,12 @@
+from typing import List
+
 from eyja.hubs.base_hub import BaseHub
 from eyja.hubs.config_hub import ConfigHub
 from influxdb_client import InfluxDBClient, Point, WritePrecision
 from influxdb_client.client.write_api import SYNCHRONOUS
 
+from eyja_influxdb.models import TimePoint
+
 
 class InfluxDBHub(BaseHub):
     bucket: str
@@ -24,17 +28,7 @@ class InfluxDBHub(BaseHub):
         return await super().init()
 
     @classmethod
-    async def send(cls, data):
+    async def send(cls, points: List[TimePoint]):
         write_api = cls.client.write_api(write_options=SYNCHRONOUS)
 
-        point = Point(data.measurement)
-
-        for tag_name, tag_value in data.tags.items():
-            point = point.tag(tag_name, tag_value)
-
-        for field_name, field_value in data.fields.items():
-            point = point.field(field_name, field_value)
-
-        point = point.time(data.time, WritePrecision.NS)
-
-        write_api.write(cls.bucket, cls.org, point)
+        write_api.write(cls.bucket, cls.org, [p.get_point() for p in points])
